@@ -413,9 +413,14 @@ class BinaryManager:
                     if self.use_angr:
                         disassembly = self.angr_project.arch.disasm(data, offset)
                     else:
+                        logger.debug(f"Disassembly for {data} @ {offset}")
                         disassembler = Cs(CS_ARCH_X86, CS_MODE_64)
+                        disassembler.detail = True
                         disassembly = "\n".join(
-                            map(str, disassembler.disasm(data, offset))
+                            map(
+                                lambda i: f"{i.address:#x}: {i.mnemonic} {i.op_str}",
+                                disassembler.disasm(data, offset),
+                            )
                         )
 
                     logger.debug(f"Disassembly of data for label {write.data.label}:")
